==> haskell-cprng-aes-0.6.1-239-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cprng-aes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cprng-aes
version:              0.6.1
visibility:           public
id:                   cprng-aes-0.6.1-Ii6qmEiiwRd37FtpqyVCGs
key:                  cprng-aes-0.6.1-Ii6qmEiiwRd37FtpqyVCGs
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-cprng-aes
synopsis:
    Crypto Pseudo Random Number Generator using AES in counter mode.

description:
    Simple crypto pseudo-random-number-generator with really good randomness property.

    Using ent, a randomness property maker on one 1Mb sample:
    Entropy = 7.999837 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 237.02
    Arithmetic mean value of data bytes is 127.3422 (127.5 = random)
    Monte Carlo value for Pi is 3.143589568 (error 0.06 percent)

    Compared to urandom with the same sampling:
    Entropy = 7.999831 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 246.63
    Arithmetic mean value of data bytes is 127.6347 (127.5 = random).
    Monte Carlo value for Pi is 3.132465868 (error 0.29 percent).

category:             Cryptography
abi:                  9cb1ecdc95039239032c83e3f99d80f0
exposed:              True
exposed-modules:      Crypto.Random.AESCtr
hidden-modules:       Crypto.Random.AESCtr.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/cprng-aes-0.6.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/cprng-aes-0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cprng-aes
hs-libraries:         HScprng-aes-0.6.1-Ii6qmEiiwRd37FtpqyVCGs
depends:
    base-4.15.0.0 byteable-0.1.1-6a8DqkMpvw66y0umFUx8qQ
    bytestring-0.10.12.1 cipher-aes-0.2.11-2yZRRjJrigR2ORcvVSVCkF
    crypto-random-0.0.9-Aa2NFm6A81NKt0wPvYJjyR

haddock-interfaces:   /usr/share/doc/haskell-cprng-aes/html/cprng-aes.haddock
haddock-html:         /usr/share/doc/haskell-cprng-aes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cprng-aes-0.6.1-240-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cprng-aes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cprng-aes
version:              0.6.1
visibility:           public
id:                   cprng-aes-0.6.1-68N1n3XXj9WKIx177qKsRa
key:                  cprng-aes-0.6.1-68N1n3XXj9WKIx177qKsRa
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-cprng-aes
synopsis:
    Crypto Pseudo Random Number Generator using AES in counter mode.

description:
    Simple crypto pseudo-random-number-generator with really good randomness property.

    Using ent, a randomness property maker on one 1Mb sample:
    Entropy = 7.999837 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 237.02
    Arithmetic mean value of data bytes is 127.3422 (127.5 = random)
    Monte Carlo value for Pi is 3.143589568 (error 0.06 percent)

    Compared to urandom with the same sampling:
    Entropy = 7.999831 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 246.63
    Arithmetic mean value of data bytes is 127.6347 (127.5 = random).
    Monte Carlo value for Pi is 3.132465868 (error 0.29 percent).

category:             Cryptography
abi:                  3d7e9df36372b6038fd21cf54e775310
exposed:              True
exposed-modules:      Crypto.Random.AESCtr
hidden-modules:       Crypto.Random.AESCtr.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/cprng-aes-0.6.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/cprng-aes-0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cprng-aes
hs-libraries:         HScprng-aes-0.6.1-68N1n3XXj9WKIx177qKsRa
depends:
    base-4.15.0.0 byteable-0.1.1-6a8DqkMpvw66y0umFUx8qQ
    bytestring-0.10.12.1 cipher-aes-0.2.11-2yZRRjJrigR2ORcvVSVCkF
    crypto-random-0.0.9-9zbeXQMihQ19y41uEMaT7n

haddock-interfaces:   /usr/share/doc/haskell-cprng-aes/html/cprng-aes.haddock
haddock-html:         /usr/share/doc/haskell-cprng-aes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
